==> mutual_credit-5.0.8.tar.gz: mutual_credit/src/Plugin/Block/BalanceHistory.php <==
<?php

namespace Drupal\mcapi\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\mcapi\Entity\Wallet;

/**
 * Provides a user balances block.
 *
 * @Block(
 *   id = "mcapi_balance_history",
 *   admin_label = @Translation("Balance over time"),
 *   category = @Translation("Community Accounting")
 * )
 */
class BalanceHistory extends WalletContextBlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $conf = parent::defaultConfiguration();
    // These are the same defaults as in hook_theme.
    return $conf += ['width' => 300, 'height' => 150];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $form['width'] = [
      '#title' => t('Width in pixels'),
      '#description' => t('The height is half the width'),
      '#type' => 'number',
      '#min' => 0,
      '#default_value' => $this->configuration['width'],
      '#max_size' => 4,
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   *
   * How to calculate the block title? Could be singular or plural, for example.
   */
  public function getTitle() {
    $num = min(count($this->getWallets()), count($this->configuration['curr_ids']));
    return $this->formatPlural(
      $num,
      'Balance over time',
      'Balances over time'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $renderable = [];
    foreach ($this->getWallets() as $wallet) {
      $renderable['w-'.$wallet->id().$curr_id] = [
        '#type' => 'balance_histories',
        '#wallet' => $this->wallets,
        '#curr_ids' => $this->configuration['curr_ids'],
        '#width' => $this->configuration['width']
      ];
    }
    return $renderable += parent::build();
  }



}

==> mutual_credit-5.0.12.tar.gz: mutual_credit/src/Plugin/Block/BalanceHistory.php <==
<?php

namespace Drupal\mcapi\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\mcapi\Entity\Wallet;
use Drupal\mcapi\Entity\Currency;

/**
 * Provides a user balances block.
 *
 * @Block(
 *   id = "mcapi_balance_history",
 *   admin_label = @Translation("Balance over time"),
 *   category = @Translation("Community Accounting")
 * )
 */
class BalanceHistory extends WalletContextBlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $conf = parent::defaultConfiguration();
    // These are the same defaults as in hook_theme.
    return $conf += ['width' => 300, 'height' => 150];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $form['width'] = [
      '#title' => t('Width in pixels'),
      '#description' => t('The height is half the width'),
      '#type' => 'number',
      '#min' => 0,
      '#default_value' => $this->configuration['width'],
      '#max_size' => 4,
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   *
   * How to calculate the block title? Could be singular or plural, for example.
   */
  public function getTitle() {
    $num = min(count($this->getWallets()), count($this->configuration['curr_ids']));
    return $this->formatPlural(
      $num,
      'Balance over time',
      'Balances over time'
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $renderable = [];
    foreach ($this->getWallets() as $wallet) {
      foreach (Currency::loadMultiple($this->configuration['curr_ids']) as $currency) {
        $renderable['w-'.$wallet->id().$curr_id] = [
          '#type' => 'balance_history',
          '#wallet' => $this->wallets,
          '#currency' => $currency,
          '#width' => $this->configuration['width']
        ];
      }
    }
    return $renderable += parent::build();
  }



}
